Struct redox_users::AllGroups
source · pub struct AllGroups { /* private fields */ }Expand description
Implementations
sourceimpl AllGroups
impl AllGroups
sourcepub fn add_group(&mut self, builder: GroupBuilder) -> Result<&Group, Error>
pub fn add_group(&mut self, builder: GroupBuilder) -> Result<&Group, Error>
Consumes a builder, adding a new group to this AllGroups. Returns a
reference to the created Group.
Make sure to call AllGroups::save in order for the new group to be
applied to the system.
Defaults
If a builder is not passed a group id (GroupBuilder::gid) before
being passed to this function, AllGroups::get_unique_id is used.
If the builder is not passed any users (GroupBuilder::user), the
group will still be created.