[][src]Struct redox_users::Config

pub struct Config { /* fields omitted */ }

A generic configuration that allows fine control of an AllUsers or AllGroups.

auth_delay is not used by AllGroups

In most situations, Config::default will work just fine. The other fields are for finer control if it is required.

Example

use std::time::Duration;

let cfg = Config::default()
    .min_id(500)
    .max_id(1000)
    .auth_delay(Duration::from_secs(5));

Implementations

impl Config[src]

pub fn auth_delay(self, delay: Duration) -> Config[src]

Set the delay for a failed authentication. Default is 3 seconds.

pub fn min_id(self, id: usize) -> Config[src]

Set the smallest ID possible to use when finding an unused ID.

pub fn max_id(self, id: usize) -> Config[src]

Set the largest possible ID to use when finding an unused ID.

pub fn scheme(self, scheme: String) -> Config[src]

Set the scheme relative to which the AllUsers or AllGroups should be looking for its data files. This is a compromise between exposing implementation details and providing fine enough control over the behavior of this API.