Marker types for User and AllUsers.
User
AllUsers
Marker type indicating that a User only has access to world-readable user information, and cannot authenticate.
Marker type indicating that a User has access to all user information, including password hashes.