[−][src]Struct redox_users::AllGroups
AllGroups provides
(borrowed) access to all groups on the system. Note that this
struct implements All, for a bunch of convenience
functions.
General notes that also apply to this struct may be found with
AllUsers.
Implementations
impl AllGroups[src]
pub fn new(config: Config) -> Result<AllGroups>[src]
Create a new AllGroups.
pub fn add_group(
&mut self,
name: &str,
gid: usize,
users: &[&str]
) -> Result<()>[src]
&mut self,
name: &str,
gid: usize,
users: &[&str]
) -> Result<()>
Adds a group with the specified attributes to this AllGroups.
This function is classified as a mutating operation,
and users must therefore call save
in order for the new group to be applied to the system.
pub fn save(&self) -> Result<()>[src]
Syncs the data stored in this AllGroups instance to the filesystem.
To apply changes from an AllGroups, you MUST call this function!